``astrodynx.twobody``
======================

``twobody``
------------

.. automodule:: astrodynx.twobody
    :members:
    :undoc-members:
    :show-inheritance:

``twobody.orb_integrals``
-------------------------

.. automodule:: astrodynx.twobody.orb_integrals
    :members:
    :undoc-members:
    :show-inheritance:

``twobody.kepler_equation``
---------------------------

.. automodule:: astrodynx.twobody.kepler_equation
    :members:
    :undoc-members:
    :show-inheritance:

``twobody.ivp``
---------------

.. automodule:: astrodynx.twobody.ivp
    :members:
    :undoc-members:
    :show-inheritance:
